#!/bin/bash
#
# packager          : Frederic Boulet <bipbip> bipbiponlinux~AT~gmail.com
#
# dernières révisions : 24/03/2009
#
# package			: monkey-bubble
# homepage			: http://www.monkey-bubble.org/
# source location	: http://home.gna.org/monkeybubble/downloads/monkey-bubble-0.4.0.tar.gz
# dependency        : SDL

softname='monkey-bubble'
softversion='0.4.0'
packageversion='62.1'

#
# ZenWalk standard: type CPUet architecture
#
# arch='i486' -> le compileur utilise seulement les instructions 80486
# cpu='i686'  -> optimisation faîte pour PII et >
#
arch='i486'
cpu='i686'

#
# destination du package
#
prefix=/usr

#
# log
#
(

#
# building-computer dependent: the number of parallel 'jobs' of 'make'
#
# "gros" PC: 6 compilations à la fois
#
# numjobs='-j6'
#
# "léger" PC: 2 compilations à la fois
#
numjobs='-j2'

#
# paramètres pour compiler
#
buildir=$(pwd)
src="$buildir/$softname-$softversion"
srcpkg="$buildir/$softname-$softversion.tar.gz"
package="$softname-$softversion-$arch-$packageversion"
dest="$buildir/$package"
source=http://home.gna.org/monkeybubble/downloads/$softname-$softversion.tar.gz

#
# preparer le répertoire qui accueillera la compilation
#
rm -rf $dest
mkdir -p $dest
mkdir -p $dest/install
mkdir -p $dest/$prefix/bin
mkdir -p $dest/usr/share/applications
mkdir -p $dest/usr/share/icons/hicolor/48x48/apps
mkdir -p $dest/usr/doc
mkdir -p $dest/usr/src/$softname-$softversion

#
# mettre le slack-desc en place. 
#
cat <<EOF > $dest/install/slack-desc 
            |-----handy-ruler------------------------------------------------------|
monkey-bubble: monkey-bubble - A Bust'n'Move clone
monkey-bubble:
monkey-bubble: It currently supports 1 and 2 player games, is levelcompatible with
monkey-bubble: frozen bubble, and features svg vector graphics for resolution 
monkey-bubble: independent display.
monkey-bubble: 
monkey-bubble: 
monkey-bubble:
monkey-bubble: 
monkey-bubble:
monkey-bubble:
EOF

#
# Verifie si package est present
#
if [ -f $softname-$softversion.tar.gz ]; then
	echo "Source file already here, no need to download";
else
 	echo "Downloading source"
	wget -c --no-check-certificate $source
fi

#
# extraire les sources
#
# tar.gz : tar zxvf $srcpkg
# tar.bz2: tar xjvf $srcpkg
# tgz    : tar xzvf $srcpkg
#
cd $buildir
tar xvzf $srcpkg
cd $src	

#
# "faire" le package package
#
export CFLAGS="-O2 -march=$arch -mtune=$cpu"
export CXXFLAGS="-O2 -march=$arch -mtune=$cpu"

./configure \
	--program-prefix="" \
	--program-suffix="" \
	--prefix="/usr" \
	--sysconfdir="/etc" \
	--localstatedir="/var" \
	--mandir="/usr/man" \
	--infodir="/usr/info" \
	--enable-static="no" \
	--enable-shared="yes" \
	--with-gconf-source="xml::/etc/gconf/gconf.xml.defaults" \
	--build=$arch-slackware-linux || exit
	
#
# "faire" le package package
#
make 

#
# installer le package dans son répertoire de destination
#
make install DESTDIR=$dest

#
# gconf stuff
# 
 export GCONF_CONFIG_SOURCE="xml::$dest/etc/gconf/gconf.xml.defaults"
 if [ -d $dest/etc/gconf/schemas ]; then
     install -v -d -m755 $dest/etc/gconf/gconf.xml.defaults
     SCHEMAS=$dest/etc/gconf/schemas
     for schema in $SCHEMAS/*.schemas; do
         gconftool-2 --makefile-install-rule $schema
     done
     # Reset / Verify correct permissions
     ( cd $dest/etc/gconf ; find . -type d -exec chmod 755 {} \; )
     ( cd $dest/etc/gconf ; find . -type f -exec chmod 644 {} \; )
 fi 

#
# "faire" icon
#
cd $dest/usr/share/icons/hicolor/48x48/apps/
ln -s ../../../../pixmaps/monkey-bubble-icon.png  $softname.png

#
# "faire" .desktop
#
cat << "EOF" > $dest/usr/share/applications/$softname.desktop
[Desktop Entry]
Name=Monkey bubble
Exec=monkey-bubble
Icon=monkey-bubble
Terminal=false
Type=Application
Categories=Game;ArcadeGame;
Encoding=UTF-8
EOF

#
# ajout des fichiers de docs, infos, ...
#
	cd $src
    mkdir -p $dest/usr/doc/$softname-$softversion
    cp -a \
      AUTHORS COPYING INSTALL README ChangeLog\
      $dest/usr/doc/$softname-$softversion

#
# Stripper les éxécutables
# (Commenter ces lignes si besoin d'infos de débuggage)
#
( cd $dest
  find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
  find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
)

#
# Compresser les pages Man
#
( cd $dest/$prefix/man
  find . -name "*.?" | xargs gzip -9
)

#
# Mettre le zenbuild à sa place
#
cd $buildir
cp build-$softname.sh $dest/$prefix/src/$softname-$softversion

#
# fixer les permissions
#
chown -R root.root $dest

cd $dest
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;

#
# fabriquer le zenpackage
#
cd $dest
makepkg -l y -c n $dest.tgz

#
# produire la signature md5 du package
#
cd $buildir
md5sum $package.tgz > $package.md5

#
# produire le fichier .dep
#
cd $buildir
echo -e "alsa-lib,atk,audiofile,avahi,bzip2,cairo,dbus,dbus-glib,\
e2fsprogs,esound,expat,fontconfig,freetype,gcc,gconf,glib2,glitz,\
gnome-keyring,gnome-vfs,gstreamer,gtk+2,libart_lgpl,libbonobo,\
libbonoboui,libcroco,libglade,libgnome,libgnomecanvas,libgnomeui,\
libgsf,libpng,librsvg,libxml2,openssl,orbit2,pango,pixman,\
popt,xcb,xorg-libs,zlib" > $package.dep

#
# produire le fichier src
#
echo http://zenwalk.pinguix.com/user-accounts/bip/EXTRA/games/monkey-bubble/source/build-monkey-bubble.sh > $package.src
echo $source >> $package.src

#
# supprimer source
#
rm -rf $src
rm -rf $dest

#
# log
#
) 2>&1 | tee "$softname-$softversion-build.log"
